@@ -21,6 +21,7 @@ from .tools import copy_dir_contents, rsync
 from .tools import abort
 from .tools import __assure_gitignore
 from .tools import _write_file
+from .tools import bashfind
 
 ADDONS_OCA = "addons_OCA"
 
@@ -205,8 +206,8 @@ class OdooShRepo(object):
 
     def iterate_all_modules(self, version, path=None):
         path = path or self.ocapath
-        for path in path.rglob("*"):
-            if not path.is_dir():
+        for path in bashfind(path=self.root, type="d", wholename=f"*/{version}/*"):
+            if '.git' in path.parts:
                 continue
             if path.parent.name != str(version):
                 continue
@@ -247,9 +248,10 @@ class OdooShRepo(object):
             modulename = f"*{modulename}*"
 
         results = []
-        for match in self.ocapath.rglob(modulename):
-            if not match.is_dir():
-                continue
+        if not exact_match:
+            modulename = f"*{modulename}*"
+
+        for match in bashfind(path=self.root, type="d", name=modulename):
             if not (match / "__manifest__.py").exists():
                 continue
             if match.parent.name != self.version:
@@ -325,19 +327,15 @@ def fetch_modules(config, ctx, module):
                 transfer_module(todo)
             todos += new
 
-    _identify_duplicate_modules()
+    _identify_duplicate_modules(todos)
 
 
-def _identify_duplicate_modules():
+def _identify_duplicate_modules(check):
     # remove duplicate modules or at least identify them:
     from .module_tools import Modules, Module
 
-    modules = Modules()
-    all_modules = modules.get_all_modules_installed_by_manifest()
-    for x in all_modules:
-        for y in customs_dir().rglob(x):
-            if not y.is_dir():
-                continue
+    for x in sorted(check):
+        for y in bashfind(path=customs_dir(), type='d', name=x):
             if not (y / "__manifest__.py").exists():
                 continue
             module = Module.get_by_name(x)
